==> ktp-text-ui-15.04.0.tar.xz: ktp-text-ui-15.04.0/filters/otr/ktptextui_message_filter_otr.desktop.cmake <==
[Desktop Entry]
Name=OTR
Name[ast]=OTR
Name[bs]=OTR
Name[ca]=OTR
Name[cs]=OTR
Name[da]=OTR
Name[de]=OTR
Name[el]=OTR
Name[en_GB]=OTR
Name[es]=OTR
Name[et]=OTR
Name[fi]=OTR
Name[fr]=OTR
Name[hu]=OTR
Name[it]=OTR
Name[nb]=OTR
Name[nl]=OTR
Name[nn]=OTR
Name[pl]=OTR
Name[pt]=OTR
Name[pt_BR]=OTR
Name[sk]=OTR
Name[sl]=OTR
Name[sr]=ОТР
Name[sr@ijekavian]=ОТР
Name[sr@ijekavianlatin]=OTR
Name[sr@latin]=OTR
Name[sv]=OTR
Name[uk]=OTR
Name[x-test]=xxOTRxx
Name[zh_CN]=非公开加密
Name[zh_TW]=OTR
Comment=If a message is an OTR message, it will not be shown
Comment[ast]=Si un mensaxe ye OTR, nun s'amosará
Comment[bs]=Ako je poruka OTR poruka, ona neće biti prikazana
Comment[ca]=Si un missatge és OTR, no es mostrarà
Comment[cs]=Pokud je zpráva OTR, nebude zobrazena
Comment[da]=Hvis en besked er en OTR-besked, vil den ikke blive vist
Comment[de]=Wenn eine Nachricht vom Typ OTR ist, wird sie nicht angezeigt
Comment[el]=Αν ένα μήνυμα είναι μήνυμα OTR, δεν θα εμφανιστεί
Comment[en_GB]=If a message is an OTR message, it will not be shown
Comment[es]=Si un mensaje es un mensaje OTR, no se mostrará
Comment[et]=Kui tegu on OTR-sõnumiga, seda ei näidata.
Comment[fi]=Jos viesti on OTR-viesti, sitä ei näytetä
Comment[fr]=Si un message est un message OTR, il ne sera pas affiché
Comment[hu]=Ha az üzenet egy OTR üzenet, nem lesz megjelenítve
Comment[it]=Se un messaggio è un messaggio OTR, non sarà mostrato
Comment[nb]=Hvis en melding er en OTR-melding blir den ikke vist
Comment[nl]=Als een bericht een OTR-bericht is, zal het niet getoond worden
Comment[pl]=Jeśli wiadomość jest wiadomością OTR, to nie zostanie pokazana
Comment[pt]=Se uma dada mensagem for em OTR, não será apresentada
Comment[pt_BR]=Se uma determinada mensagem for em OTR, não será apresentada
Comment[sk]=Ak správa je OTR správa, nebude zobrazená
Comment[sl]=Če je sporočilo vrste OTR, ne bo prikazano
Comment[sr]=Ако је порука ОТР порука, неће бити приказана.
Comment[sr@ijekavian]=Ако је порука ОТР порука, неће бити приказана.
Comment[sr@ijekavianlatin]=Ako je poruka OTR poruka, neće biti prikazana.
Comment[sr@latin]=Ako je poruka OTR poruka, neće biti prikazana.
Comment[sv]=Om ett meddelande är ett OTR-meddelande, kommer det inte att visas
Comment[uk]=Якщо повідомлення є повідомленням OTR, його не буде показано
Comment[x-test]=xxIf a message is an OTR message, it will not be shownxx
Comment[zh_CN]=如果消息是非公开消息，该消息将不会显示
Comment[zh_TW]=如果是私下加密（Off The Record）的訊息，則不會顯示
Encoding=UTF-8
Type=Service
ServiceTypes=KTpTextUi/MessageFilter

X-KDE-Library=ktptextui_message_filter_otr
X-KDE-PluginInfo-Author=Marcin Ziemiński
X-KDE-PluginInfo-Email=zieminn@gmail.com
X-KDE-PluginInfo-Name=otr
X-KDE-PluginInfo-Version=@KTP_TEXT_UI_VERSION@
X-KDE-PluginInfo-Website=http://community.kde.org/KTp
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-EnabledByDefault=true
X-KTp-PluginInfo-Version=@KTP_MESSAGE_FILTER_FRAMEWORK_VERSION@

==> ktp-text-ui-15.04.3.tar.xz: ktp-text-ui-15.04.3/filters/otr/ktptextui_message_filter_otr.desktop.cmake <==
[Desktop Entry]
Name=OTR
Name[ast]=OTR
Name[bs]=OTR
Name[ca]=OTR
Name[cs]=OTR
Name[da]=OTR
Name[de]=OTR
Name[el]=OTR
Name[en_GB]=OTR
Name[es]=OTR
Name[et]=OTR
Name[fi]=OTR
Name[fr]=OTR
Name[hu]=OTR
Name[it]=OTR
Name[nb]=OTR
Name[nl]=OTR
Name[nn]=OTR
Name[pl]=OTR
Name[pt]=OTR
Name[pt_BR]=OTR
Name[ro]=OTR
Name[ru]=OTR
Name[sk]=OTR
Name[sl]=OTR
Name[sr]=ОТР
Name[sr@ijekavian]=ОТР
Name[sr@ijekavianlatin]=OTR
Name[sr@latin]=OTR
Name[sv]=OTR
Name[uk]=OTR
Name[x-test]=xxOTRxx
Name[zh_CN]=非公开加密
Name[zh_TW]=OTR
Comment=If a message is an OTR message, it will not be shown
Comment[ast]=Si un mensaxe ye OTR, nun s'amosará
Comment[bs]=Ako je poruka OTR poruka, ona neće biti prikazana
Comment[ca]=Si un missatge és OTR, no es mostrarà
Comment[cs]=Pokud je zpráva OTR, nebude zobrazena
Comment[da]=Hvis en besked er en OTR-besked, vil den ikke blive vist
Comment[de]=Wenn eine Nachricht vom Typ OTR ist, wird sie nicht angezeigt
Comment[el]=Αν ένα μήνυμα είναι μήνυμα OTR, δεν θα εμφανιστεί
Comment[en_GB]=If a message is an OTR message, it will not be shown
Comment[es]=Si un mensaje es un mensaje OTR, no se mostrará
Comment[et]=Kui tegu on OTR-sõnumiga, seda ei näidata.
Comment[fi]=Jos viesti on OTR-viesti, sitä ei näytetä
Comment[fr]=Si un message est un message OTR, il ne sera pas affiché
Comment[hu]=Ha az üzenet egy OTR üzenet, nem lesz megjelenítve
Comment[it]=Se un messaggio è un messaggio OTR, non sarà mostrato
Comment[nb]=Hvis en melding er en OTR-melding blir den ikke vist
Comment[nl]=Als een bericht een OTR-bericht is, zal het niet getoond worden
Comment[pl]=Jeśli wiadomość jest wiadomością OTR, to nie zostanie pokazana
Comment[pt]=Se uma dada mensagem for em OTR, não será apresentada
Comment[pt_BR]=Se uma determinada mensagem for em OTR, não será apresentada
Comment[ru]=Если сообщение зашифровано по протоколу OTR, то оно не будет показано
Comment[sk]=Ak správa je OTR správa, nebude zobrazená
Comment[sl]=Če je sporočilo vrste OTR, ne bo prikazano
Comment[sr]=Ако је порука ОТР порука, неће бити приказана.
Comment[sr@ijekavian]=Ако је порука ОТР порука, неће бити приказана.
Comment[sr@ijekavianlatin]=Ako je poruka OTR poruka, neće biti prikazana.
Comment[sr@latin]=Ako je poruka OTR poruka, neće biti prikazana.
Comment[sv]=Om ett meddelande är ett OTR-meddelande, kommer det inte att visas
Comment[uk]=Якщо повідомлення є повідомленням OTR, його не буде показано
Comment[x-test]=xxIf a message is an OTR message, it will not be shownxx
Comment[zh_CN]=如果消息是非公开消息，该消息将不会显示
Comment[zh_TW]=如果是私下加密（Off The Record）的訊息，則不會顯示
Encoding=UTF-8
Type=Service
ServiceTypes=KTpTextUi/MessageFilter

X-KDE-Library=ktptextui_message_filter_otr
X-KDE-PluginInfo-Author=Marcin Ziemiński
X-KDE-PluginInfo-Email=zieminn@gmail.com
X-KDE-PluginInfo-Name=otr
X-KDE-PluginInfo-Version=@KTP_TEXT_UI_VERSION@
X-KDE-PluginInfo-Website=http://community.kde.org/KTp
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-EnabledByDefault=true
X-KTp-PluginInfo-Version=@KTP_MESSAGE_FILTER_FRAMEWORK_VERSION@
